@@ -44,13 +44,7 @@
 #' An analytical method is available for all types of regression except for weighted Deming.
 #' For Passing-Bablok regression the option "analytical" calculates confidence intervals for the regression parameters
 #' according to the non-parametric approach given in the original reference.
-#' Note that estimating resampling based confidence intervals for Passing-Bablok regressions can take very long
-#' for larger data sets due to the high computational complexity of the algorithm. To mitigate this drawback
-#' an adaption of the Passing-Bablok algorithm has been implemented ("PaBaLarge"), which yields approximative results. This approach
-#' does not build the complete upper triangular matrix of all 'n*(n-1)/2' slopes. It subdivides the range of slopes into
-#' 'NBins' classes, and sorts each slope into one of these bins. The remaining steps are the same as for the exact "PaBa"
-#' algorithm, except that these are performed on the binned slopes instead of operating on the matrix of slopes.
-#'
+#' 
 #' The "jackknife" (or leave one out resampling) method was suggested by Linnet for
 #' calculating confidence intervals of regression parameters
 #' of Deming and weighted Deming regression. It is possible to calculate jackknife confidence
@@ -64,6 +58,23 @@
 #' The "nestedbootstrap" method can be very time-consuming but is necessary for calculating t-bootstrap
 #' confidence intervals for weighted Deming or Passing-Bablok regression. For these regression methods there are no analytical
 #' solutions for computing standard errors, which therefore have to be obtained by nested bootstrapping.
+#' 
+#' Note that estimating resampling based confidence intervals for Passing-Bablok regressions can take very long
+#' for larger data sets due to the high computational complexity of the algorithm. To mitigate this drawback
+#' an adaption of the Passing-Bablok algorithm has been implemented (\code{"PaBaLarge"}), which yields approximative results. This approach
+#' does not build the complete upper triangular matrix of all 'n*(n-1)/2' slopes. It subdivides the range of slopes into
+#' 'NBins' classes, and sorts each slope into one of these bins. The remaining steps are the same as for the exact \code{"PaBa"}
+#' algorithm, except that these are performed on the binned slopes instead of operating on the matrix of slopes.
+#' 
+#' Our implementation of exact Passing-Bablok regression (\code{"PaBa"}) provides two alternative metrics for regression slopes which
+#' can result in different regression estimates.
+#' As a robust regression method PaBa is essentially invariant to the parameterization of regression slopes,
+#' however in the case of an even number of all pairwise slopes the two central slopes are averaged to estimate the final regression slope.
+#' In this situation using an angle based metric (\code{slope.measure="radian"}) will result in
+#' a regression estimate that is geometrically centered between the two central slopes, whereas the tangent measure (\code{slope.measure="tangent"})
+#' proposed in Passing and Bablok (1983) will be geometrically biased towards a higher slope. See below for a pathological example.
+#' Note that the difference between the two measures is neglectable for data sets with reasonable sample size (N>20) and correlation.   
+#'
 #'
 #' @param x measurement values of reference method, or two column matrix.
 #' @param y measurement values of test method.
@@ -79,14 +90,14 @@
 #'          \code{"Deming"} - Deming regression.\cr 
 #'          \code{"WDeming"} - weighted Deming regression.\cr
 #'          \code{"PaBa"} - Passing-Bablok regression.\cr  
-#'          \code{"PaBaLarge"} - approximative Passing-Bablok regression for large datasets, operating on \code{NBins} classes which each slope
-#'                               is classified to instead of building the complete triangular matrix of all N*N/2 slopes. 
+#'          \code{"PaBaLarge"} - approximative Passing-Bablok regression for large datasets, operating on \code{NBins} classes of constant slope angle which each slope
+#'                               is classified to instead of building the complete triangular matrix of all N*N/2 slopes.
 #' @param method.ci method of confidence interval calculation. The function 
 #'         contains four basic methods for calculation of confidence intervals for regression coefficients.
 #'          \code{"analytical"} - with parametric method.\cr
 #'          \code{"jackknife"} - with leave one out resampling.\cr
 #'          \code{"bootstrap"} - with ordinary non-parametric bootstrap resampling.\cr
-#'          \code{"nested bootstrap"} - with ordinary nonparametric bootstrap resampling.\cr 
+#'          \code{"nested bootstrap"} - with ordinary non-parametric bootstrap resampling.\cr 
 #' @param method.bootstrap.ci bootstrap based confidence interval estimation method. 
 #' @param nsamples number of bootstrap samples.
 #' @param nnested number of nested bootstrap samples.
@@ -96,6 +107,9 @@
 #' @param threshold numerical tolerance for weighted Deming iterative algorithm convergence.
 #' @param na.rm remove measurement pairs that contain missing values (Default is FALSE).
 #' @param NBins number of bins used when 'reg.method="PaBaLarge"' to classify each slope in one of 'NBins' bins covering the range of all slopes
+#' @param slope.measure angular measure of pairwise slopes used for exact PaBa regression (see below for details).\cr   
+#'          \code{"radian"} - for data sets with even sample numbers median slope is calculated as average of two central slope angles.\cr
+#'          \code{"tangent"} - for data sets with even sample numbers median slope is calculated as average of two central slopes (tan(angle)).\cr
 #' @return "MCResult" object containing regression results. The function \code{\link{getCoefficients}} or
 #'          \code{\link{printSummary}} can be used to obtain or print a summary of the results.
 #'          The function \code{\link{getData}} allows to see the original data.
@@ -142,28 +156,43 @@
 #' 
 #'              \emph{CLSI EP9-A2}. Method Comparison and Bias Estimation Using Patient Samples; Approved Guideline.
 #' @seealso \code{\link{plotDifference}}, \code{\link{plot.mcr}}, \code{\link{getResiduals}}, \code{\link{plotResiduals}}, \code{\link{calcResponse}}, \code{\link{calcBias}}, \code{\link{plotBias}}, \code{\link{compareFit}}
-#' @author Ekaterina Manuilova \email{ekaterina.manuilova@@contractors.roche.com}, Andre Schuetzenmeister \email{andre.schuetzenmeister@@roche.com}, Fabian Model \email{fabian.model@@roche.com}
+#' @author Ekaterina Manuilova \email{ekaterina.manuilova@@roche.com}, Andre Schuetzenmeister \email{andre.schuetzenmeister@@roche.com}, Fabian Model \email{fabian.model@@roche.com}
 #' @examples
-#'     library("mcr")
-#'     data(creatinine,package="mcr")
-#'     x <- creatinine$serum.crea
-#'     y <- creatinine$plasma.crea
-#'     # Deming regression fit.
-#'     # The confidence intercals for regression coefficients
-#'     # are calculated with analytical method
-#'     model1<- mcreg(x,y,error.ratio=1,method.reg="Deming", method.ci="analytical",
-#'                      mref.name = "serum.crea", mtest.name = "plasma.crea", na.rm=TRUE)
-#'     # Results
-#'     printSummary(model1)
-#'     getCoefficients(model1)
-#'     plot(model1)
-#'     # Deming regression fit.
-#'     # The confidence intervals for regression coefficients
-#'     # are calculated with bootstrap (BCa) method
-#'     model2<- mcreg(x,y,error.ratio=1,method.reg="Deming",
-#'                    method.ci="bootstrap", method.bootstrap.ci = "BCa",
-#'                    mref.name = "serum.crea", mtest.name = "plasma.crea", na.rm=TRUE)
-#'     compareFit(model1, model2)
+#' library("mcr")
+#' data(creatinine,package="mcr")
+#' x <- creatinine$serum.crea
+#' y <- creatinine$plasma.crea
+#' # Deming regression fit.
+#' # The confidence intercals for regression coefficients
+#' # are calculated with analytical method
+#' model1<- mcreg(x,y,error.ratio=1,method.reg="Deming", method.ci="analytical",
+#'                mref.name = "serum.crea", mtest.name = "plasma.crea", na.rm=TRUE)
+#' # Results
+#' printSummary(model1)
+#' getCoefficients(model1)
+#' plot(model1)
+#' # Deming regression fit.
+#' # The confidence intervals for regression coefficients
+#' # are calculated with bootstrap (BCa) method
+#' model2<- mcreg(x,y,error.ratio=1,method.reg="Deming",
+#'                method.ci="bootstrap", method.bootstrap.ci = "BCa",
+#'                mref.name = "serum.crea", mtest.name = "plasma.crea", na.rm=TRUE)
+#' compareFit(model1, model2) 
+#' 
+#' ## Pathological example of Passing-Bablok regression where measure for slope angle matters  
+#' x1 <- 1:10; y1 <- 0.5*x1; x <- c(x1,y1); y <- c(y1,x1) 
+#' m1 <- mcreg(x,y,method.reg="PaBa",method.ci="analytical",slope.measure="radian",
+#'             mref.name="X",mtest.name="Y")
+#' m2 <- mcreg(x,y,method.reg="PaBa",method.ci="analytical",slope.measure="tangent",
+#'             mref.name="X",mtest.name="Y")
+#' plot(m1, add.legend=FALSE,identity=FALSE,
+#'      main="Radian vs. tangent slope measures in Passing-Bablok regression\n(pathological example)",
+#'      ci.area=FALSE,add.cor=FALSE)
+#' plot(m2, ci.area=FALSE,reg.col="darkgreen",reg.lty=2,identity=FALSE,add.legend=FALSE,
+#'      draw.points=FALSE,add=TRUE,add.cor=FALSE)
+#' includeLegend(place="topleft",models=list(m1,m2),model.names=c("PaBa Radian","PaBa Tangent"),
+#'               colors=c("darkblue","darkgreen"),lty=c(1,2),design="1",digits=2)
+
 mcreg <- function(x,y=NULL,error.ratio=1,alpha=0.05,
               mref.name = NULL,
               mtest.name = NULL, 
@@ -172,12 +201,13 @@ mcreg <- function(x,y=NULL,error.ratio=1,alpha=0.05,
               method.ci=c("bootstrap","jackknife","analytical","nestedbootstrap"),
               method.bootstrap.ci=c("quantile","Student","BCa","tBoot"),
               nsamples=999,nnested=25,rng.seed=NULL,rng.kind="Mersenne-Twister",
-              iter.max=30,threshold=0.000001,na.rm=FALSE, NBins=1000000)
+              iter.max=30,threshold=0.000001,na.rm=FALSE, NBins=1000000,slope.measure=c("radian","tangent"))
 {
 	## Match choice parameters
     method.reg <- match.arg(method.reg)
     method.ci <- match.arg(method.ci)
     method.bootstrap.ci <- match.arg(method.bootstrap.ci)
+    slope.measure <- match.arg(slope.measure)
   
 	## Check input data
     if( method.reg %in% c("Deming", "WDeming") )
@@ -295,7 +325,7 @@ mcreg <- function(x,y=NULL,error.ratio=1,alpha=0.05,
                 ## Compute slope matrix
                 angM <- mc.calcAngleMat(data[,"x"], data[,"y"], posCor=posCor)
                 ## Regression
-                mc.res <- mc.paba(angM, data[,"x"], data[,"y"], posCor=posCor, alpha=alpha)		
+                mc.res <- mc.paba(angM, data[,"x"], data[,"y"], posCor=posCor, alpha=alpha, slope.measure=slope.measure)		
             }
             else    # PaBaLarge: regression using the approximative PaBa-algorithm
             {
@@ -327,7 +357,7 @@ mcreg <- function(x,y=NULL,error.ratio=1,alpha=0.05,
     {
         cat("Jackknife based calculation of standard error and confidence intervals according to Linnet's method.\n")
         res <- mc.bootstrap(method.reg=method.reg, jackknife=TRUE,bootstrap="none", X=data[,"x"], Y=data[,"y"],
-                            error.ratio=error.ratio, nsamples=nsamples, NBins=NBins,
+                            error.ratio=error.ratio, nsamples=nsamples, NBins=NBins, slope.measure=slope.measure,
                             threshold=threshold, iter.max=iter.max, nnested=nnested)
         B0jack <- res$B0jack
         B1jack <- res$B1jack
@@ -362,14 +392,14 @@ mcreg <- function(x,y=NULL,error.ratio=1,alpha=0.05,
         #if (method.ci=="nestedbootstrap" & method.bootstrap.ci %in% c("Student","BCa")) warning("You need nested bootstrap only for 'tBoot' method.\n Please use option 'bootstrap' ")
         if(method.bootstrap.ci == "BCa") 
         {
-            res <- mc.bootstrap(method.reg=method.reg, jackknife=TRUE, bootstrap=method.ci, X=data[,"x"], Y=data[,"y"], NBins=NBins,
+            res <- mc.bootstrap(method.reg=method.reg, jackknife=TRUE, bootstrap=method.ci, X=data[,"x"], Y=data[,"y"], NBins=NBins, slope.measure=slope.measure,
                                 error.ratio=error.ratio, nsamples=nsamples, threshold=threshold, iter.max=iter.max, nnested=nnested)
             B0jack <- res$B0jack
             B1jack <- res$B1jack
 		} 
         else 
         {
-            res <- mc.bootstrap(method.reg=method.reg, jackknife=FALSE, bootstrap=method.ci, X=data[,"x"], Y=data[,"y"], NBins=NBins,
+            res <- mc.bootstrap(method.reg=method.reg, jackknife=FALSE, bootstrap=method.ci, X=data[,"x"], Y=data[,"y"], NBins=NBins, slope.measure=slope.measure,
                                 error.ratio=error.ratio, nsamples=nsamples, threshold=threshold, iter.max=iter.max, nnested=nnested)
         }               
         xmean <- res$xmean
